PGConnectionAdapter class

Constructors

PGConnectionAdapter()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

connection ↔ Connection
getter/setter pair

Static Methods

init(String uri) → Future<void>
initPool(String uri, {int minConnections = 1, int maxConnections = 5}) → Future<void>